Package io.github.classgraph
Class AnnotationClassRef
java.lang.Object
io.github.classgraph.AnnotationClassRef
public class AnnotationClassRef extends Object
Stores the type descriptor of a
Class<?>, as found in an annotation parameter value.-
Method Summary
Modifier and Type Method Description booleanequals(Object obj)ClassInfogetClassInfo()Get the class info.StringgetName()Get the name of the referenced class.inthashCode()Class<?>loadClass()Loads the referenced class, returning aClass<?>reference for the referenced class.Class<?>loadClass(boolean ignoreExceptions)Loads the referenced class, returning aClass<?>reference for the referenced class.StringtoString()
-
Method Details
-
getName
Get the name of the referenced class.- Returns:
- The name of the referenced class.
-
loadClass
Loads the referenced class, returning aClass<?>reference for the referenced class.- Parameters:
ignoreExceptions- if true, ignore exceptions and instead return null if the class could not be loaded.- Returns:
- The
Class<?>reference for the referenced class. - Throws:
IllegalArgumentException- if the class could not be loaded and ignoreExceptions was false.
-
loadClass
Loads the referenced class, returning aClass<?>reference for the referenced class.- Returns:
- The
Class<?>reference for the referenced class. - Throws:
IllegalArgumentException- if the class could not be loaded.
-
getClassInfo
Get the class info.- Returns:
- The
ClassInfoobject for the referenced class, or null if the referenced class was not encountered during scanning (i.e. if no ClassInfo object was created for the class during scanning). N.B. even if this method returns null,loadClass()may be able to load the referenced class by name.
-
hashCode
public int hashCode() -
equals
-
toString
-