Class AnnotationInfo
- java.lang.Object
-
- io.github.classgraph.AnnotationInfo
-
- All Implemented Interfaces:
HasName,java.lang.Comparable<AnnotationInfo>
public class AnnotationInfo extends java.lang.Object implements java.lang.Comparable<AnnotationInfo>, HasName
Holds metadata about a specific annotation instance on a class, method, method parameter or field.
-
-
Field Summary
Fields Modifier and Type Field Description protected ScanResultscanResultThe scan result.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description intcompareTo(AnnotationInfo o)booleanequals(java.lang.Object obj)ClassInfogetClassInfo()Get the class info.protected java.lang.StringgetClassName()Get the name of the annotation class, forgetClassInfo().AnnotationParameterValueListgetDefaultParameterValues()Get the default parameter values.java.lang.StringgetName()Get the name.AnnotationParameterValueListgetParameterValues()Get the parameter values.inthashCode()booleanisInherited()Checks if the annotation is inherited.java.lang.annotation.AnnotationloadClassAndInstantiate()Load theAnnotationclass corresponding to thisAnnotationInfoobject, by callinggetClassInfo().loadClass(), then create a new instance of the annotation, with the annotation parameter values obtained from thisAnnotationInfoobject, possibly overriding default annotation parameter values obtained from callinggetClassInfo()thenClassInfo.getAnnotationDefaultParameterValues().java.lang.StringtoString()
-
-
-
Field Detail
-
scanResult
protected transient ScanResult scanResult
The scan result.
-
-
Method Detail
-
getName
public java.lang.String getName()
Get the name.
-
isInherited
public boolean isInherited()
Checks if the annotation is inherited.- Returns:
- true if this annotation is meta-annotated with
Inherited.
-
getDefaultParameterValues
public AnnotationParameterValueList getDefaultParameterValues()
Get the default parameter values.- Returns:
- the list of default parameter values for this annotation, or the empty list if none.
-
getParameterValues
public AnnotationParameterValueList getParameterValues()
Get the parameter values.- Returns:
- The parameter values of this annotation, including any default parameter values inherited from the annotation class definition, or the empty list if none.
-
getClassName
protected java.lang.String getClassName()
Get the name of the annotation class, forgetClassInfo().- Returns:
- the class name
-
getClassInfo
public ClassInfo getClassInfo()
Get the class info.- Returns:
- The
ClassInfoobject for the annotation class.
-
loadClassAndInstantiate
public java.lang.annotation.Annotation loadClassAndInstantiate()
Load theAnnotationclass corresponding to thisAnnotationInfoobject, by callinggetClassInfo().loadClass(), then create a new instance of the annotation, with the annotation parameter values obtained from thisAnnotationInfoobject, possibly overriding default annotation parameter values obtained from callinggetClassInfo()thenClassInfo.getAnnotationDefaultParameterValues().Note that the returned
Annotationwill have some sort ofInvocationHandlerproxy type, such asio.github.classgraph.features.$Proxy4orcom.sun.proxy.$Proxy6. This is an unavoidable side effect of the fact that concreteAnnotationinstances cannot be instantiated directly. (ClassGraph uses the same approach that the JDK uses to instantiate annotations from a map.) However, proxy instances are handled specially when it comes to casting andinstanceof: you are able to cast the returned proxy instance to the annotation type, andinstanceofchecks against the annotation class will succeed.Of course another option you have for getting the concrete annotations, rather than instantiating the annotations on a
ClassInfoobject via this method, is to callClassInfo.loadClass(), and read the annotations directly from the returnedClassobject.- Returns:
- The new
Annotationinstance, as a dynamic proxy object that can be cast to the expected annotation type.
-
compareTo
public int compareTo(AnnotationInfo o)
- Specified by:
compareToin interfacejava.lang.Comparable<AnnotationInfo>
-
equals
public boolean equals(java.lang.Object obj)
- Overrides:
equalsin classjava.lang.Object
-
hashCode
public int hashCode()
- Overrides:
hashCodein classjava.lang.Object
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-