Package io.github.classgraph
Class AnnotationParameterValue
java.lang.Object
io.github.classgraph.AnnotationParameterValue
- All Implemented Interfaces:
HasName,Comparable<AnnotationParameterValue>
public class AnnotationParameterValue extends Object implements HasName, Comparable<AnnotationParameterValue>
A wrapper used to pair annotation parameter names with annotation parameter values.
-
Method Details
-
getName
Get the annotation parameter name. -
getValue
Get the annotation parameter value.- Returns:
- The annotation parameter value. May be one of the following types:
- String for string constants
- String[] for arrays of strings
- A boxed type, e.g. Integer or Character, for primitive-typed constants
- A 1-dimensional primitive-typed array (i.e. int[], long[], short[], char[], byte[], boolean[], float[], or double[]), for arrays of primitives
- A 1-dimensional
Object[] array for array types (and then the array element type may be one of the types in this list) AnnotationEnumValue, for enum constants (this wraps the enum class and the string name of the constant)AnnotationClassRef, for Class references within annotations (this wraps the name of the referenced class)AnnotationInfo, for nested annotations
-
toString
-
compareTo
- Specified by:
compareToin interfaceComparable<AnnotationParameterValue>
-
equals
-
hashCode
public int hashCode()
-