Package io.github.classgraph
Class ClassGraphException
- java.lang.Object
-
- java.lang.Throwable
-
- java.lang.Exception
-
- java.lang.RuntimeException
-
- java.lang.IllegalArgumentException
-
- io.github.classgraph.ClassGraphException
-
- All Implemented Interfaces:
java.io.Serializable
public class ClassGraphException extends java.lang.IllegalArgumentExceptionAn unchecked exception that is thrown when an error state occurs or an unhandled exception is caught during scanning.(Extends
IllegalArgumentException, which extendsRuntimeException, so either of the more generic exceptions may be caught.)- See Also:
- Serialized Form
-
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static ClassGraphExceptionnewClassGraphException(java.lang.String message)Static factory method to stop IDEs from auto-completing ClassGraphException after "new ClassGraph".static ClassGraphExceptionnewClassGraphException(java.lang.String message, java.lang.Throwable cause)Static factory method to stop IDEs from auto-completing ClassGraphException after "new ClassGraph".
-
-
-
Method Detail
-
newClassGraphException
public static ClassGraphException newClassGraphException(java.lang.String message)
Static factory method to stop IDEs from auto-completing ClassGraphException after "new ClassGraph".- Parameters:
message- the message- Returns:
- the ClassGraphException
-
newClassGraphException
public static ClassGraphException newClassGraphException(java.lang.String message, java.lang.Throwable cause) throws ClassGraphException
Static factory method to stop IDEs from auto-completing ClassGraphException after "new ClassGraph".- Parameters:
message- the messagecause- the cause- Returns:
- the ClassGraphException
- Throws:
ClassGraphException- the class graph exception
-
-