Package io.github.classgraph
Class PackageInfoList
java.lang.Object
- All Implemented Interfaces:
Serializable,Cloneable,Iterable<PackageInfo>,Collection<PackageInfo>,List<PackageInfo>,RandomAccess
public class PackageInfoList extends MappableInfoList<PackageInfo>
A list of
PackageInfo objects.- See Also:
- Serialized Form
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfacePackageInfoList.PackageInfoFilterFilter anPackageInfoListusing a predicate mapping anPackageInfoobject to a boolean, producing anotherPackageInfoListfor all items in the list for which the predicate is true. -
Method Summary
Modifier and Type Method Description voidadd(int index, T element)booleanadd(T element)booleanaddAll(int index, Collection<? extends T> c)booleanaddAll(Collection<? extends T> c)voidclear()PackageInfoListfilter(PackageInfoList.PackageInfoFilter filter)Find the subset of thePackageInfoobjects in this list for which the given filter predicate is true.Iterator<T>iterator()ListIterator<T>listIterator()Tremove(int index)booleanremove(Object o)booleanremoveAll(Collection<?> c)booleanretainAll(Collection<?> c)Tset(int index, T element)Methods inherited from class java.util.ArrayList
clone, contains, ensureCapacity, forEach, get, indexOf, isEmpty, lastIndexOf, listIterator, removeIf, replaceAll, size, sort, spliterator, subList, toArray, toArray, trimToSize
-
Method Details
-
filter
Find the subset of thePackageInfoobjects in this list for which the given filter predicate is true.- Parameters:
filter- ThePackageInfoList.PackageInfoFilterto apply.- Returns:
- The subset of the
PackageInfoobjects in this list for which the given filter predicate is true.
-
add
public boolean add(T element) -
add
public void add(int index, T element) -
remove
-
remove
public T remove(int index) -
addAll
-
addAll
-
removeAll
-
retainAll
-
clear
public void clear() -
set
public T set(int index, T element) -
iterator
-
listIterator
- Specified by:
listIteratorin interfaceList<T>- Overrides:
listIteratorin classArrayList<T>
-