Uses of Class
io.github.classgraph.PackageInfo
-
Packages that use PackageInfo Package Description io.github.classgraph -
-
Uses of PackageInfo in io.github.classgraph
Methods in io.github.classgraph that return PackageInfo Modifier and Type Method Description static PackageInfoPackageInfo. getPackage(String packageName, Map<String,PackageInfo> packageNameToPackageInfo)Get thePackageInfoobject for the named package, also creatingPackageInfoobjects for any needed parent packages.PackageInfoModuleInfo. getPackageInfo(String packageName)Get thePackageInfoobject for the named packagein this module, or null if the package was not found in this module.PackageInfoScanResult. getPackageInfo(String packageName)Get thePackageInfoobject for the named package, or null if no package of the requested name was found during the scan.PackageInfoPackageInfo. getParent()The parent package of this package, or null if this is the root package.Methods in io.github.classgraph that return types with arguments of type PackageInfo Modifier and Type Method Description List<PackageInfo>PackageInfo. getChildren()The child packages of this package, or the empty list if none.Methods in io.github.classgraph with parameters of type PackageInfo Modifier and Type Method Description booleanPackageInfoList.PackageInfoFilter. accept(PackageInfo packageInfo)Whether or not to allow anPackageInfolist item through the filter.intPackageInfo. compareTo(PackageInfo o)Method parameters in io.github.classgraph with type arguments of type PackageInfo Modifier and Type Method Description static PackageInfoPackageInfo. getPackage(String packageName, Map<String,PackageInfo> packageNameToPackageInfo)Get thePackageInfoobject for the named package, also creatingPackageInfoobjects for any needed parent packages.
-