Package io.github.classgraph
Class AnnotationClassRef
- java.lang.Object
-
- io.github.classgraph.AnnotationClassRef
-
public class AnnotationClassRef extends java.lang.ObjectStores the type descriptor of aClass<?>, as found in an annotation parameter value.
-
-
Field Summary
Fields Modifier and Type Field Description protected ScanResultscanResultThe scan result.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(java.lang.Object obj)protected voidfindReferencedClassNames(java.util.Set<java.lang.String> classNames)ClassInfogetClassInfo()Get the class info.protected java.lang.StringgetClassName()The name of the class (used bygetClassInfo()to fetch theClassInfoobject for the class).java.lang.StringgetName()Get the name of the referenced class.inthashCode()java.lang.Class<?>loadClass()Loads the referenced class, returning aClass<?>reference for the referenced class.java.lang.Class<?>loadClass(boolean ignoreExceptions)Loads the referenced class, returning aClass<?>reference for the referenced class.java.lang.StringtoString()
-
-
-
Field Detail
-
scanResult
protected transient ScanResult scanResult
The scan result.
-
-
Method Detail
-
getName
public java.lang.String getName()
Get the name of the referenced class.- Returns:
- The name of the referenced class.
-
loadClass
public java.lang.Class<?> loadClass(boolean ignoreExceptions)
Loads the referenced class, returning aClass<?>reference for the referenced class.- Parameters:
ignoreExceptions- if true, ignore exceptions and instead return null if the class could not be loaded.- Returns:
- The
Class<?>reference for the referenced class. - Throws:
java.lang.IllegalArgumentException- if the class could not be loaded and ignoreExceptions was false.
-
loadClass
public java.lang.Class<?> loadClass()
Loads the referenced class, returning aClass<?>reference for the referenced class.- Returns:
- The
Class<?>reference for the referenced class. - Throws:
java.lang.IllegalArgumentException- if the class could not be loaded.
-
getClassName
protected java.lang.String getClassName()
The name of the class (used bygetClassInfo()to fetch theClassInfoobject for the class).- Returns:
- The class name.
-
getClassInfo
public ClassInfo getClassInfo()
Get the class info.- Returns:
- The
ClassInfoobject for the referenced class, or null if the referenced class was not encountered during scanning (i.e. if no ClassInfo object was created for the class during scanning). N.B. even if this method returns null,loadClass()may be able to load the referenced class by name.
-
findReferencedClassNames
protected void findReferencedClassNames(java.util.Set<java.lang.String> classNames)
-
hashCode
public int hashCode()
- Overrides:
hashCodein classjava.lang.Object
-
equals
public boolean equals(java.lang.Object obj)
- Overrides:
equalsin classjava.lang.Object
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-