Package io.github.classgraph
Class PackageInfoList
- java.lang.Object
-
- java.util.AbstractCollection<E>
-
- java.util.AbstractList<E>
-
- java.util.ArrayList<T>
-
- io.github.classgraph.InfoList<T>
-
- io.github.classgraph.MappableInfoList<PackageInfo>
-
- io.github.classgraph.PackageInfoList
-
- All Implemented Interfaces:
java.io.Serializable,java.lang.Cloneable,java.lang.Iterable<PackageInfo>,java.util.Collection<PackageInfo>,java.util.List<PackageInfo>,java.util.RandomAccess
public class PackageInfoList extends MappableInfoList<PackageInfo>
A list ofPackageInfoobjects.- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfacePackageInfoList.PackageInfoFilterFilter anPackageInfoListusing a predicate mapping anPackageInfoobject to a boolean, producing anotherPackageInfoListfor all items in the list for which the predicate is true.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description PackageInfoListfilter(PackageInfoList.PackageInfoFilter filter)Find the subset of thePackageInfoobjects in this list for which the given filter predicate is true.-
Methods inherited from class io.github.classgraph.MappableInfoList
asMap, containsName, get
-
Methods inherited from class io.github.classgraph.InfoList
getAsStrings, getNames
-
Methods inherited from class java.util.ArrayList
add, add, addAll, addAll, clear, clone, contains, ensureCapacity, equals, forEach, get, hashCode, indexOf, isEmpty, iterator, lastIndexOf, listIterator, listIterator, remove, remove, removeAll, removeIf, removeRange, replaceAll, retainAll, set, size, sort, spliterator, subList, toArray, toArray, trimToSize
-
-
-
-
Method Detail
-
filter
public PackageInfoList filter(PackageInfoList.PackageInfoFilter filter)
Find the subset of thePackageInfoobjects in this list for which the given filter predicate is true.- Parameters:
filter- ThePackageInfoList.PackageInfoFilterto apply.- Returns:
- The subset of the
PackageInfoobjects in this list for which the given filter predicate is true.
-
-